@@ -1,15 +1,13 @@
 use 5.010;    # perldoc perl5101delta -> bugfix related to handling of /m
 use strict;
 use warnings;
+use utf8;
 
 package Dist::Zilla::Plugin::MetaProvides::Package;
 BEGIN {
   $Dist::Zilla::Plugin::MetaProvides::Package::AUTHORITY = 'cpan:KENTNL';
 }
-{
-  $Dist::Zilla::Plugin::MetaProvides::Package::VERSION = '1.15000002';
-}
-
+$Dist::Zilla::Plugin::MetaProvides::Package::VERSION = '1.15000003';
 # ABSTRACT: Extract namespaces/version from traditional packages for provides
 
 use Moose qw( with has around );
@@ -24,197 +22,343 @@ use Data::Dump 1.16 ();
 
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 use namespace::autoclean;
 with 'Dist::Zilla::Role::MetaProvider::Provider';
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 has '+meta_noindex' => ( default => sub { 1 } );
 
 
+
+
+
+
+
+
+
+
+
 sub provides {
-    my $self        = shift;
-    my $get_records = sub {
-        $self->_packages_for( $_->name, $_->content );
-    };
-    my (@records);
-    for my $file ( @{ $self->_found_files() } ) {
-        push @records, $self->_packages_for( $file->name, $file->content );
-    }
-    return $self->_apply_meta_noindex(@records);
+  my $self = shift;
+  my (@records);
+  for my $file ( @{ $self->_found_files() } ) {
+    push @records, $self->_packages_for( $file->name, $file->content );
+  }
+  return $self->_apply_meta_noindex(@records);
 }
 
 
+
+
+
 has '_package_blacklist' => (
-    isa => HashRef [Str],
-    traits  => [ 'Hash', ],
-    is      => 'rw',
-    default => sub {
-        return { map { $_ => 1 } qw( main DB ) };
-    },
-    handles => { _blacklist_contains => 'exists', },
+  isa => HashRef [Str],
+  traits  => [ 'Hash', ],
+  is      => 'rw',
+  default => sub {
+    return { map { $_ => 1 } qw( main DB ) };
+  },
+  handles => { _blacklist_contains => 'exists', },
 );
 
 
+
+
+
+
+
+
+
 sub _packages_for {
-    my ( $self, $filename, $content ) = @_;
+  my ( $self, $filename, $content ) = @_;
 
-    my $fh = IO::String->new($content);
+  my $fh = IO::String->new($content);
 
-    my $meta = Module::Metadata->new_from_handle( $fh, $filename, collect_pod => 0 );
+  my $meta = Module::Metadata->new_from_handle( $fh, $filename, collect_pod => 0 );
 
-    if ( not $meta ) {
-        $self->log_fatal("Can't extract metadata from $filename");
-    }
+  if ( not $meta ) {
+    $self->log_fatal("Can't extract metadata from $filename");
+  }
 
-    $self->log_debug(
-        "Version metadata from $filename : " . Data::Dump::dumpf(
-            $meta,
-            sub {
-                if ( ref $_[1] and $_[1]->isa('version') ) {
-                    return { dump => $_[1]->stringify };
-                }
-                return { hide_keys => ['pod_headings'], };
-            },
-        ),
+  $self->log_debug(
+    "Version metadata from $filename : " . Data::Dump::dumpf(
+      $meta,
+      sub {
+        if ( ref $_[1] and $_[1]->isa('version') ) {
+          return { dump => $_[1]->stringify };
+        }
+        return { hide_keys => ['pod_headings'], };
+      },
+    ),
+  );
+  my $remove_bad = sub {
+    my $item = shift;
+    return if $item =~ qr/\A_/msx;
+    return if $item =~ qr/::_/msx;
+    return not $self->_blacklist_contains($item);
+  };
+  my $to_record = sub {
+
+    my $v = $meta->version($_);
+    my (%struct) = (
+      module => $_,
+      file   => $filename,
+      ( ref $v ? ( version => $v->stringify ) : ( version => undef ) ),
+      parent => $self,
     );
-    my $remove_bad = sub {
-        my $item = shift;
-        return if $item =~ qr/\A_/msx;
-        return if $item =~ qr/::_/msx;
-        return not $self->_blacklist_contains($item);
-    };
-    my $to_record = sub {
+    $self->log_debug(
+      'Version metadata: ' . Data::Dump::dumpf(
+        \%struct,
+        sub {
+          return { hide_keys => ['parent'] };
+        },
+      ),
+    );
+    Dist::Zilla::MetaProvides::ProvideRecord->new(%struct);
+  };
 
-        my $v = $meta->version($_);
-        my (%struct) = (
-            module => $_,
-            file   => $filename,
-            ( ref $v ? ( version => $v->stringify ) : ( version => undef ) ),
-            parent => $self,
-        );
-        $self->log_debug(
-            'Version metadata: ' . Data::Dump::dumpf(
-                \%struct,
-                sub {
-                    return { hide_keys => ['parent'] };
-                },
-            ),
-        );
-        Dist::Zilla::MetaProvides::ProvideRecord->new(%struct);
-    };
+  ## no critic (ProhibitArrayAssignARef)
+  my @namespaces = [ $meta->packages_inside() ]->grep($remove_bad)->flatten;
 
-    ## no critic (ProhibitArrayAssignARef)
-    my @namespaces = [ $meta->packages_inside() ]->grep($remove_bad)->flatten;
+  $self->log_debug( 'Discovered namespaces: ' . Data::Dump::pp( \@namespaces ) . ' in ' . $filename );
 
-    $self->log_debug( 'Discovered namespaces: ' . Data::Dump::pp( \@namespaces ) . ' in ' . $filename );
-
-    if ( not @namespaces ) {
-        $self->log( 'No namespaces detected in file ' . $filename );
-        return ();
-    }
-    return @namespaces->map($to_record)->flatten;
+  if ( not @namespaces ) {
+    $self->log( 'No namespaces detected in file ' . $filename );
+    return ();
+  }
+  return @namespaces->map($to_record)->flatten;
 
 }
 around dump_config => sub {
-    my ( $orig, $self, @args ) = @_;
-    my $config    = $self->$orig(@args);
-    my $localconf = {};
-    for my $attribute (qw( finder )) {
-        my $pred = 'has_' . $attribute;
-        if ( $self->can($pred) ) {
-            next unless $self->$pred();
-        }
-        if ( $self->can($attribute) ) {
-            $localconf->{$attribute} = $self->$attribute();
-        }
+  my ( $orig, $self, @args ) = @_;
+  my $config    = $self->$orig(@args);
+  my $localconf = {};
+  for my $attribute (qw( finder )) {
+    my $pred = 'has_' . $attribute;
+    if ( $self->can($pred) ) {
+      next unless $self->$pred();
     }
-    $config->{ q{} . __PACKAGE__ } = $localconf;
-    return $config;
+    if ( $self->can($attribute) ) {
+      $localconf->{$attribute} = $self->$attribute();
+    }
+  }
+  for my $finder_object ( @{ $self->_finder_objects } ) {
+    $localconf->{finder_objects} = [] if not exists $localconf->{finder_objects};
+    my $object_config = {};
+
+    $object_config->{class}   = $finder_object->meta->name  if $finder_object->can('meta') and $finder_object->meta->can('name');
+    $object_config->{name}    = $finder_object->plugin_name if $finder_object->can('plugin_name');
+    $object_config->{version} = $finder_object->VERSION     if $finder_object->can('VERSION');
+
+    if ( $finder_object->can('dump_config') ) {
+      my $finder_config = $finder_object->dump_config;
+      $object_config->{config} = $finder_config if keys %{$finder_config};
+    }
+    push @{ $localconf->{finder_objects} }, $object_config;
+  }
+  $config->{ q{} . __PACKAGE__ } = $localconf;
+  return $config;
 };
 
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 has finder => (
-    isa           => 'ArrayRef[Str]',
-    is            => ro =>,
-    lazy_required => 1,
-    predicate     => has_finder =>,
+  isa           => 'ArrayRef[Str]',
+  is            => ro =>,
+  lazy_required => 1,
+  predicate     => has_finder =>,
 );
 
 
+
+
+
 has _finder_objects => (
-    isa      => 'ArrayRef',
-    is       => ro =>,
-    lazy     => 1,
-    init_arg => undef,
-    builder  => _build_finder_objects =>,
+  isa      => 'ArrayRef',
+  is       => ro =>,
+  lazy     => 1,
+  init_arg => undef,
+  builder  => _build_finder_objects =>,
 );
 
 
+
+
+
 sub _vivify_installmodules_pm_finder {
-    my ($self) = @_;
-    my $name = $self->plugin_name;
-    $name .= '/AUTOVIV/:InstallModulesPM';
-    if ( my $plugin = $self->zilla->plugin_named($name) ) {
-        return $plugin;
-    }
-    require Dist::Zilla::Plugin::FinderCode;
-    my $plugin = Dist::Zilla::Plugin::FinderCode->new(
-        {
-            plugin_name => $name,
-            zilla       => $self->zilla,
-            style       => 'grep',
-            code        => sub {
-                my ( $file, $self ) = @_;
-                local $_ = $file->name;
-                ## no critic (RegularExpressions)
-                return 1 if m{\Alib/} and m{\.(pm)$};
-                return 1 if $_ eq $self->zilla->main_module;
-                return;
-            },
-        },
-    );
-    $self->zilla->plugins->push($plugin);
+  my ($self) = @_;
+  my $name = $self->plugin_name;
+  $name .= '/AUTOVIV/:InstallModulesPM';
+  if ( my $plugin = $self->zilla->plugin_named($name) ) {
     return $plugin;
+  }
+  require Dist::Zilla::Plugin::FinderCode;
+  my $plugin = Dist::Zilla::Plugin::FinderCode->new(
+    {
+      plugin_name => $name,
+      zilla       => $self->zilla,
+      style       => 'grep',
+      code        => sub {
+        my ( $file, $self ) = @_;
+        local $_ = $file->name;
+        ## no critic (RegularExpressions)
+        return 1 if m{\Alib/} and m{\.(pm)$};
+        return 1 if $_ eq $self->zilla->main_module;
+        return;
+      },
+    },
+  );
+  $self->zilla->plugins->push($plugin);
+  return $plugin;
 }
 
 
+
+
+
 sub _build_finder_objects {
-    my ($self) = @_;
-    if ( $self->has_finder ) {
-        my @out;
-        for my $finder ( @{ $self->finder } ) {
-            my $plugin = $self->zilla->plugin_named($finder);
-            if ( not $plugin ) {
-                $self->log_fatal("no plugin named $finder found");
-            }
-            if ( not $plugin->does('Dist::Zilla::Role::FileFinder') ) {
-                $self->log_fatal("plugin $finder is not a FileFinder");
-            }
-            push @out, $plugin;
-        }
-        return \@out;
+  my ($self) = @_;
+  if ( $self->has_finder ) {
+    my @out;
+    for my $finder ( @{ $self->finder } ) {
+      my $plugin = $self->zilla->plugin_named($finder);
+      if ( not $plugin ) {
+        $self->log_fatal("no plugin named $finder found");
+      }
+      if ( not $plugin->does('Dist::Zilla::Role::FileFinder') ) {
+        $self->log_fatal("plugin $finder is not a FileFinder");
+      }
+      push @out, $plugin;
     }
-    return [ $self->_vivify_installmodules_pm_finder ];
+    return \@out;
+  }
+  return [ $self->_vivify_installmodules_pm_finder ];
 }
 
 
+
+
+
 sub _found_files {
-    my ($self) = @_;
-    my %by_name;
-    for my $plugin ( @{ $self->_finder_objects } ) {
-        for my $file ( @{ $plugin->find_files } ) {
-            $by_name{ $file->name } = $file;
-        }
+  my ($self) = @_;
+  my %by_name;
+  for my $plugin ( @{ $self->_finder_objects } ) {
+    for my $file ( @{ $plugin->find_files } ) {
+      $by_name{ $file->name } = $file;
     }
-    return [ values %by_name ];
+  }
+  return [ values %by_name ];
 }
 
 around mvp_multivalue_args => sub {
-    my ( $orig, $self, @rest ) = @_;
-    return ( 'finder', $self->$orig(@rest) );
+  my ( $orig, $self, @rest ) = @_;
+  return ( 'finder', $self->$orig(@rest) );
 };
 
 
+
+
+
+
+
+
+
+
+
 __PACKAGE__->meta->make_immutable;
 no Moose;
 1;
@@ -231,7 +375,7 @@ Dist::Zilla::Plugin::MetaProvides::Package - Extract namespaces/version from tra
 
 =head1 VERSION
 
-version 1.15000002
+version 1.15000003
 
 =head1 SYNOPSIS
 
